# ResourceRoleSpec

A ResourceRoleSpec provides the configurable details of a ResourceRole.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_type** | **str** | The type of the resource referred to by &#x60;resource_id&#x60;. | 
**role_name** | **str** | A short descriptive name used to identify the role. Unique per resource_type.  | 
**description** | **str** | A brief description of the role detailing the purpose of the role and what sort of permissions it grants.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


